package com.caimei365.user.controller;

import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.dto.ClubTemporaryDto;
import com.caimei365.user.model.dto.OnlineDto;
import com.caimei365.user.model.po.ServiceProviderPo;
import com.caimei365.user.model.vo.*;
import com.caimei365.user.service.SellerService;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.apache.commons.lang.StringUtils;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/24
 */
@Api(tags = "协销用户API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/user/seller")
public class SellerApi {

    private final SellerService sellerService;

    /**
     * 待注册机构列表
     */
    @ApiOperation("待注册机构列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "userId", required = true, value = "协销userId"),
            @ApiImplicitParam(name = "searchName", required = false, value = "搜索名称"),
            @ApiImplicitParam(name = "pageNum", required = true, value = "第几页"),
            @ApiImplicitParam(name = "pageSize", required = true, value = "一页多少条")
    })

    @GetMapping("/temporary/club")
    public ResponseJson<PageInfo<ClubTemporaryVo>> temporaryClub(Integer userId, String searchName,
                                                                 @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                 @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {
        if (userId == null) {
            return ResponseJson.error("参数异常", null);
        }
        return sellerService.temporaryClub(userId, searchName, pageNum, pageSize);
    }

    /**
     * 修改待注册机构资料
     */
    @ApiOperation("修改待注册机构资料")
    @PostMapping("/modify/temporary/club")
    public ResponseJson<String> modifyTemporaryClub(ClubTemporaryDto temporaryDto) {
        if (temporaryDto.getId() == null || StringUtils.isBlank(temporaryDto.getBindMobile())) {
            return ResponseJson.error("参数异常", null);
        }
        return sellerService.modifyTemporaryClub(temporaryDto);
    }

    /**
     * 删除待注册机构资料
     */
    @ApiOperation("删除待注册机构资料")
    @PostMapping("/delete/temporary/club")
    public ResponseJson<String> deleteTemporaryClub(OnlineDto onlineDto) {
        if (onlineDto.getId() == null) {
            return ResponseJson.error("参数异常", null);
        }
        return sellerService.deleteTemporaryClub(onlineDto.getId());
    }


    /**
     * 协销机构列表
     * 原spi的 /seller/club/list
     *
     * @param spId           协销Id
     * @param status         机构状态 0: 待升级 1：升级中 2：升级失败
     * @param type           1.我的机构2.组员机构3.待分配机构
     * @param name           机构名字关键字（搜索用）
     * @param groupServiceId 组员协销id（搜索用）
     */
    @ApiOperation("协销机构列表")
    @GetMapping("/club/list")
    public ResponseJson<PageInfo<ClubVo>> getClubList(Integer spId,
                                                      Integer status,
                                                      Integer type,
                                                      String name,
                                                      Integer userIdentity,
                                                      Integer groupServiceId,
                                                      String startTime,
                                                      String endTime,
                                                      String activeState,
                                                      String customerValue,
                                                      @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                      @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {
        if (null == spId || null == type) {
            return ResponseJson.error("spId 或 type 参数不全！", null);
        }
        return sellerService.getClubList(spId, status, type, name, userIdentity, groupServiceId, startTime, endTime, activeState, customerValue, pageNum, pageSize);
    }

    /**
     * 机构活跃分析
     */
    @ApiOperation("机构看板")
    @GetMapping("/club/livelyClub")
    public ResponseJson<Map<String, Object>> getLivelyClub(Integer spId) {
        if (null == spId ) {
            return ResponseJson.error("spId  参数不全！", null);
        }
        return sellerService.getLivelyClub(spId);
    }

    /**
     * 机构活跃分析
     * 原spi的 /seller/club/list
     *
     * @param spId           协销Id
     * @param status         机构状态
     * @param type           1.我的机构2.组员机构3.待分配机构 4 活跃机构 5 不活跃机构
     * @param name           机构名字关键字（搜索用）
     */
    @ApiOperation("机构活跃分析列表")
    @GetMapping("/club/livelyClubList")
    public ResponseJson<PaginationVo<ClubVo>> getLivelyClubList(Integer spId,
                                                                         Integer status,
                                                                         Integer type,
                                                                         String name,
                                                                         Integer userIdentity,
                                                                         @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                         @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {
        if (null == spId || null == type) {
            return ResponseJson.error("spId 或 type 参数不全！", null);
        }
        if (4 != type && 5 != type ) {
            return ResponseJson.error("type 参数错误！", null);
        }

        return sellerService.getLivelyClubList(spId, status, type, name, userIdentity, pageNum, pageSize);
    }


    /**
     * 获取相关咨询记录机构信息
     * @param spId
     * @param type
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/getIsRemarkClub")
    public ResponseJson<PaginationVo<ClubVo>> getIsRemarkClub(Integer spId, Integer type,
                                                              @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                              @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {
        if (null == spId) {
            return ResponseJson.error("协销id不能为空", null);
        }
        if (null == type) {
            return ResponseJson.error("数据类型不能为空", null);
        }
        return sellerService.getIsRemarkClub(spId, type, pageNum, pageSize);
    }

    /**
     * 机构所有咨询记录
     * @param clubId
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/getClubAllRemark")
    public ResponseJson<PaginationVo<RemarksVo>> getClubAllRemark(Integer clubId, String search,
                                                                  @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                  @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {
        if (null == clubId) {
            return ResponseJson.error(-1, "机构id不能为空", null);
        }
        return sellerService.getClubAllRemark(clubId, search, pageNum, pageSize);
    }

    @ApiOperation("组员筛选侧边栏")
    @GetMapping("/service/team")
    public ResponseJson<List<ServiceProviderVo>> getClubList(Integer spId) {
        if (null == spId) {
            return ResponseJson.error("spId 不能为空！", null);
        }
        return sellerService.getServiceTeam(spId, 1);
    }

    /**
     * 所有的机构列表
     * 原spi的 /seller/findAllClub
     *
     * @param searchWord 关键字（搜索用）
     */
    @ApiOperation("所有的机构列表(搜索)")
    @GetMapping("/club/all")
    public ResponseJson<PageInfo<ClubVo>> getAllClubList(String searchWord,
                                                         @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                         @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {
        return sellerService.getAllClubList(searchWord, pageNum, pageSize);
    }

    /**
     * 协销个人中心
     *
     * @param userId 协销userId
     */
    @GetMapping("/home")
    public ResponseJson<ServiceProviderPo> getSellerHome(Integer userId) {
        if (null == userId) {
            return ResponseJson.error("参数异常：用户Id不能为空！", null);
        }
        return sellerService.getSellerHome(userId);
    }

    /**
     * 更新协销信息
     */
    @GetMapping("/setHome")
    public ResponseJson<ServiceProviderPo> setSellerHome(ServiceProviderPo serviceProviderPo) {
        if (null == serviceProviderPo.getUserId()) {
            return ResponseJson.error("参数异常：用户Id不能为空！", null);
        }
        return sellerService.setSellerHome(new ServiceProviderPo()
                .setUserId(serviceProviderPo.getUserId())
                .setImage(serviceProviderPo.getImage())
                .setQrCode(serviceProviderPo.getQrCode()));

    }

    /**
     * 机构访问列表
     */
    @GetMapping("/getBehaviorRecordClub")
    public ResponseJson<List<CmBehaviorRecordVo>> getBehaviorRecordClub(Integer type, Integer spId, String accDateTime) {
        return sellerService.getBehaviorRecordClub(type, spId, accDateTime);

    }

    /**
     * 机构访问详情
     */
    @GetMapping("/getBehaviorRecordClubFrom")
    public ResponseJson<List<CmBehaviorRecordVo>> getBehaviorRecordClubFrom(Integer type, Integer spId, Integer clubId, String accessTime) {
        return sellerService.getBehaviorRecordClubFrom(type, spId, clubId, accessTime);
    }

    /**
     * 机构重点访问页面
     * @param clubId
     * @return
     */
    @ApiOperation("机构重点访问页面")
    @ApiImplicitParam(required = true, name = "clubId", value = "机构Id")
    @GetMapping("/getClubKeynoteRecord")
    public ResponseJson<PageInfo<RetuenDataVo>> getClubKeynoteRecord(Integer clubId,
                                                              @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                              @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {

        if (null == clubId) {
            return ResponseJson.error(-1, "机构id不能为空", null);
        }
        return sellerService.getClubRecord(clubId, pageNum, pageSize);
    }

    /**
     * 协销不活跃机构
     * @param serviceProviderId
     * @param pageNum
     * @param pageSize
     * @return
     */
    @ApiOperation("协销不活跃机构")
    @ApiImplicitParam(required = true, name = "serviceProviderId", value = "协销Id")
    @GetMapping("/getUnActiveClubList")
    public ResponseJson<PageInfo<ClubVo>> getUnActiveClubList(Integer serviceProviderId,
                                                              @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                              @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {
        if (null == serviceProviderId) {
            return ResponseJson.error(-1, "协销Id不能为空", null);
        }
        return sellerService.getUnActiveClubList(serviceProviderId, pageNum, pageSize);
    }

}
